========
Contents
========

.. toctree::
   :maxdepth: 2

   readme
   installation
   usage
   reference/index
   contributing
   changelog

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

